/*
 * The MIT License
 *
 *  Copyright (c) 2015, Mahmoud Ben Hassine (mahmoud@benhassine.fr)
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */

package org.easybatch.core.impl;

import org.easybatch.core.api.Record;
import org.easybatch.core.api.handler.IgnoredRecordHandler;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * A No Operation {@link IgnoredRecordHandler} implementation used by default by easy batch engine.
 *
 * @author Chellan https://github.com/chellan
 */
class NoOpIgnoredRecordHandler implements IgnoredRecordHandler {

    private static final Logger LOGGER = Logger.getLogger(NoOpIgnoredRecordHandler.class.getName());

    /**
     * @param record - the ignored record to handle
     */
    @Override
    public void handle(final Record record) {
        LOGGER.log(Level.SEVERE, "The record mapper returned null for record {0}, this record will be ignored", record);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void handle(final Record record, final Throwable throwable) {
        LOGGER.log(Level.SEVERE, "An exception occurred while attempting to map record " + record, throwable);
    }

}
