/*
 *  The MIT License
 *
 *   Copyright (c) 2015, Mahmoud Ben Hassine (mahmoud@benhassine.fr)
 *
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *   THE SOFTWARE.
 */

package org.easybatch.core.writer;

import org.easybatch.core.reader.IterableMultiRecordReader;
import org.junit.Before;
import org.junit.Test;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import static org.assertj.core.api.Assertions.assertThat;
import static org.easybatch.core.impl.EngineBuilder.aNewEngine;

/**
 * Test class for {@link CollectionMultiRecordWriter}.
 *
 * @author Mahmoud Ben Hassine (mahmoud@benhassine.fr)
 */
public class CollectionMultiRecordWriterTest {

    private List<String> input, output;

    private CollectionMultiRecordWriter collectionMultiRecordWriter;

    @Before
    public void setUp() throws Exception {
        input = Arrays.asList("foo", "bar");
        output = new ArrayList<String>();
        collectionMultiRecordWriter = new CollectionMultiRecordWriter(output);
    }

    @Test
    public void testWriteRecord() throws Exception {
        collectionMultiRecordWriter.writeRecord(input);

        assertThat(output).isNotEmpty().hasSize(2).containsExactly("foo", "bar");
    }

    @Test
    public void integrationTest() throws Exception {

        aNewEngine()
                .reader(new IterableMultiRecordReader<String>(input, 2))
                .writer(collectionMultiRecordWriter)
                .build().call();

        assertThat(output).isNotEmpty().hasSize(2).containsExactly("foo", "bar");
    }
}